aescrypt

package
v1.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	Iterations = 20000 // Iterations is the number of iterations used for key derivation
	KeySize    = 32    // KeySize is the size of the key used for encryption and decryption (32=AES-256)
)

Variables

This section is empty.

Functions

func Decrypt

func Decrypt(ciphertext, password []byte) (plaintext []byte, err error)

func DecryptString

func DecryptString(ciphertext, password string) (plaintext string, err error)

func Encrypt

func Encrypt(plaintext, password []byte) (ciphertext []byte, err error)

func EncryptString

func EncryptString(plaintext, password string) (ciphertext string, err error)

Types

This section is empty.

Jump to