Documentation
¶
Index ¶
- Constants
- func Decrypt(ciphertext, password []byte) (plaintext []byte, err error)
- func DecryptString(ciphertext, password string) (plaintext string, err error)
- func Encrypt(plaintext, password []byte) (ciphertext []byte, err error)
- func EncryptString(plaintext, password string) (ciphertext string, err error)
Constants ¶
const ( Iterations = 20000 // Iterations is the number of iterations used for key derivation KeySize = 32 // KeySize is the size of the key used for encryption and decryption (32=AES-256) )
Variables ¶
This section is empty.
Functions ¶
func DecryptString ¶
func EncryptString ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.